@@ -1,8 +1,17 @@
 #include <features.h>
 #ifdef __UCLIBC_HAVE_LFS__
-#define _FILE_OFFSET_BITS   64
-#define __USE_LARGEFILE64
-#define __USE_FILE_OFFSET64
+#if defined _FILE_OFFSET_BITS && _FILE_OFFSET_BITS != 64 
+#undef _FILE_OFFSET_BITS
+#define	_FILE_OFFSET_BITS   64
+#endif
+#ifndef __USE_LARGEFILE64
+# define __USE_LARGEFILE64	1
+#endif
+/* We absolutely do _NOT_ want interfaces silently
+ * renamed under us or very bad things will happen... */
+#ifdef __USE_FILE_OFFSET64
+# undef __USE_FILE_OFFSET64
+#endif
 #include <dirent.h>
 #include <errno.h>
 #include <stdlib.h>
